<?xml version="1.0"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="text"/>
<xsl:strip-space elements="*"/>

<xsl:include href="util.xslt"/>
	
<xsl:template match="/">
	<xsl:apply-templates select="project"/>
</xsl:template>

<xsl:template match="project">
	<xsl:apply-templates select="name" mode="source"/>
	<xsl:apply-templates select="deb-section"/>
	<xsl:apply-templates select="deb-priority"/>
	<xsl:apply-templates select="maintainer"/>
	<xsl:text>Standards-Version: 1:3.3.3-2</xsl:text>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
	<xsl:apply-templates select="name" mode="package"/>
	<xsl:apply-templates select="architecture"/>
	<xsl:apply-templates select="deb-depends"/>
	<xsl:apply-templates select="deb-recommends"/>
	<xsl:apply-templates select="one-liner"/>
	<xsl:apply-templates select="overview"/>
</xsl:template>

<xsl:template match="name" mode="source">
	<xsl:text>Source: </xsl:text>
	<xsl:call-template name="replace-with">
		<xsl:with-param name="str" select="."/>
		<xsl:with-param name="substr" select="'_'"/>
		<xsl:with-param name="replacement" select="'-'"/>
	</xsl:call-template>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="name" mode="package">
	<xsl:text>Package: </xsl:text>
	<xsl:call-template name="replace-with">
		<xsl:with-param name="str" select="."/>
		<xsl:with-param name="substr" select="'_'"/>
		<xsl:with-param name="replacement" select="'-'"/>
	</xsl:call-template>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="deb-section">
	<xsl:text>Section: </xsl:text>
	<xsl:value-of select="."/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="deb-priority">
	<xsl:text>Priority: </xsl:text>
	<xsl:value-of select="."/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="maintainer">
	<xsl:text>Maintainer: </xsl:text>
	<xsl:value-of select="."/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="architecture">
	<xsl:text>Architecture: </xsl:text>
	<xsl:value-of select="."/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="deb-depends">
	<xsl:text>Depends: </xsl:text>
	<xsl:value-of select="."/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="deb-recommends">
	<xsl:text>Recommends: </xsl:text>
	<xsl:value-of select="."/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="one-liner">
	<xsl:text>Description: </xsl:text>
	<xsl:value-of select="."/>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="overview">
	<xsl:apply-templates select="*"/>
</xsl:template>

<xsl:template match="para">
	<xsl:value-of select="$tab"/>
	<xsl:call-template name="fmt">
		<xsl:with-param name="str">
			<xsl:value-of select="."/>
		</xsl:with-param>
		<xsl:with-param name="before">
			<xsl:text> </xsl:text>
		</xsl:with-param>
	</xsl:call-template>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="screen">
	<xsl:call-template name="fmt">
		<xsl:with-param name="str">
			<xsl:value-of select="."/>
		</xsl:with-param>
		<xsl:with-param name="before">
			<xsl:text> </xsl:text>
		</xsl:with-param>
	</xsl:call-template>
	<xsl:value-of select="$cr"/>
</xsl:template>

<xsl:template match="itemizedlist">
	<xsl:for-each select="listitem">
	<xsl:text> o</xsl:text>
	<xsl:call-template name="fmt">
		<xsl:with-param name="str">
			<xsl:value-of select="."/>
		</xsl:with-param>
		<xsl:with-param name="before">
			<xsl:text> </xsl:text>
		</xsl:with-param>
	</xsl:call-template>
	<xsl:value-of select="$cr"/>
	</xsl:for-each>
</xsl:template>

<xsl:template match="variablelist">
	<xsl:for-each select="varlistentry">
	<xsl:value-of select="term"/>
	<xsl:value-of select="$cr"/>
	<xsl:call-template name="fmt">
		<xsl:with-param name="str">
			<xsl:value-of select="listitem"/>
		</xsl:with-param>
		<xsl:with-param name="before">
			<xsl:text>	</xsl:text>
		</xsl:with-param>
	</xsl:call-template>
	<xsl:value-of select="$cr"/>
	</xsl:for-each>
</xsl:template>

</xsl:stylesheet>
