<?xml version="1.0"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:variable name="cr">
<xsl:text>
</xsl:text>
</xsl:variable>

<xsl:variable name="tab">
<xsl:text>	</xsl:text>
</xsl:variable>

<xsl:template name="replace-with">
	<xsl:param name="str"/>
	<xsl:param name="substr"/>
	<xsl:param name="replacement"/>
	<xsl:variable name="first">
		<xsl:choose>
			<xsl:when test="contains($str, $substr)">
				<xsl:value-of select="substring-before($str, $substr)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$str"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="middle">
		<xsl:choose>
			<xsl:when test="contains($str, $substr)">
				<xsl:value-of select="$replacement"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text></xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="last">
		<xsl:choose>
			<xsl:when test="contains($str, $substr)">
				<xsl:choose>
					<xsl:when test="contains(substring-after($str, $substr), $substr)">
						<xsl:call-template name="replace-with">
							<xsl:with-param name="str" select="substring-after($str, $substr)"/>
							<xsl:with-param name="substr" select="substr"/>
							<xsl:with-param name="replacement" select="replacement"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="substring-after($str, $substr)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text></xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:value-of select="concat($first, $middle, $last)"/>
</xsl:template>

<xsl:template name="fmt">
	<xsl:param name="str"/>
	<xsl:param name="before"/>
	<xsl:call-template name="_fmt">
		<xsl:with-param name="str" select="$str"/>
		<xsl:with-param name="before" select="$before"/>
		<xsl:with-param name="done" select="0"/>
	</xsl:call-template>
</xsl:template>

<xsl:template name="_fmt">
	<xsl:param name="str"/>
	<xsl:param name="before"/>
	<xsl:param name="done"/>
	<xsl:variable name="s">
		<xsl:value-of select="normalize-space($str)"/>	
	</xsl:variable>
	<xsl:variable name="token-len">
		<xsl:value-of select="string-length(substring-before($s, ' ')) + 1"/>	
	</xsl:variable>
	<xsl:choose>
		<xsl:when test="$done = 0">
			<xsl:value-of select="$before"/>
			<xsl:value-of select="substring-before($s, ' ')"/>
			<xsl:text> </xsl:text>
			<xsl:call-template name="_fmt">
				<xsl:with-param name="str" select="substring-after($s, ' ')"/>
				<xsl:with-param name="before" select="$before"/>
				<xsl:with-param name="done" select="$done + $token-len + 1"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$done + $token-len &gt; 80">
			<xsl:value-of select="$cr"/>
			<xsl:call-template name="_fmt">
				<xsl:with-param name="str" select="$s"/>
				<xsl:with-param name="before" select="$before"/>
				<xsl:with-param name="done" select="0"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="substring-before($s, ' ')">
			<xsl:value-of select="substring-before($s, ' ')"/>
			<xsl:text> </xsl:text>
			<xsl:call-template name="_fmt">
				<xsl:with-param name="str" select="substring-after($s, ' ')"/>
				<xsl:with-param name="before" select="$before"/>
				<xsl:with-param name="done" select="$done + $token-len + 1"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise> <!-- no more spaces -->
			<xsl:value-of select="$s"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="_orderedlist">
	<xsl:param name="index"/>
	<xsl:param name="list"/>
	<xsl:if test="$index &lt;= count(listitem)">
		<xsl:text> </xsl:text>
		<xsl:value-of select="$index"/>
		<xsl:text>.</xsl:text>
		<xsl:call-template name="fmt">
			<xsl:with-param name="str" select="listitem[$index]"/>
			<xsl:with-param name="before">
				 <xsl:text> </xsl:text>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:value-of select="$cr"/>
		<xsl:value-of select="$cr"/>
		<xsl:call-template name="_orderedlist">
			<xsl:with-param name="index" select="$index + 1"/>
			<xsl:with-param name="str" select="."/>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template match="orderedlist">
	<xsl:variable name="index">1</xsl:variable>
	<xsl:call-template name="_orderedlist">
		<xsl:with-param name="index" select="$index"/>
		<xsl:with-param name="list" select="."/>
	</xsl:call-template>
</xsl:template>

<xsl:template match="itemizedlist">
	<xsl:for-each select="listitem">
	<xsl:text> o</xsl:text>
	<xsl:call-template name="fmt">
		<xsl:with-param name="str" select="."/>
		<xsl:with-param name="before">
			<xsl:text> </xsl:text>
		</xsl:with-param>
	</xsl:call-template>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
	</xsl:for-each>
</xsl:template>

<xsl:template match="variablelist">
	<xsl:for-each select="varlistentry">
	<xsl:value-of select="term"/>
	<xsl:value-of select="$cr"/>
	<xsl:call-template name="fmt">
		<xsl:with-param name="str" select="listitem"/>
		<xsl:with-param name="before">
			<xsl:text>	</xsl:text>
		</xsl:with-param>
	</xsl:call-template>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
	</xsl:for-each>
</xsl:template>

<xsl:template match="para">
	<xsl:call-template name="fmt">
		<xsl:with-param name="str" select="."/>
	</xsl:call-template>
	<xsl:value-of select="$cr"/>
	<xsl:value-of select="$cr"/>
</xsl:template>

</xsl:stylesheet>
